# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.Notification.Management")

try:
    import winsdk.windows.applicationmodel.appointments
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.email
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class AccessoryNotificationType(enum.IntFlag):
    NONE = 0
    PHONE = 0x1
    EMAIL = 0x2
    REMINDER = 0x4
    ALARM = 0x8
    TOAST = 0x10
    APP_UNINSTALLED = 0x20
    DND = 0x40
    DRIVING_MODE = 0x80
    BATTERY_SAVER = 0x100
    MEDIA = 0x200
    CORTANA_TILE = 0x400
    TOAST_CLEARED = 0x800
    CALENDAR_CHANGED = 0x1000
    VOLUME_CHANGED = 0x2000
    EMAIL_READ_STATUS_CHANGED = 0x4000

class CalendarChangedEvent(enum.IntEnum):
    LOST_EVENTS = 0
    APPOINTMENT_ADDED = 1
    APPOINTMENT_CHANGED = 2
    APPOINTMENT_DELETED = 3
    CALENDAR_ADDED = 4
    CALENDAR_CHANGED = 5
    CALENDAR_DELETED = 6

class PhoneCallAudioEndpoint(enum.IntEnum):
    DEFAULT = 0
    SPEAKER = 1
    HANDSFREE = 2

class PhoneCallDirection(enum.IntEnum):
    INCOMING = 0
    OUTGOING = 1

class PhoneCallState(enum.IntEnum):
    UNKNOWN = 0
    RINGING = 1
    TALKING = 2
    HELD = 3
    ENDED = 4

class PhoneCallTransport(enum.IntEnum):
    CELLULAR = 0
    VOIP = 1

class PhoneLineRegistrationState(enum.IntEnum):
    DISCONNECTED = 0
    HOME = 1
    ROAMING = 2

class PhoneMediaType(enum.IntEnum):
    AUDIO_ONLY = 0
    AUDIO_VIDEO = 1

class PhoneNotificationType(enum.IntEnum):
    NEW_CALL = 0
    CALL_CHANGED = 1
    LINE_CHANGED = 2
    PHONE_CALL_AUDIO_ENDPOINT_CHANGED = 3
    PHONE_MUTE_CHANGED = 4

class PlaybackCapability(enum.IntFlag):
    NONE = 0
    PLAY = 0x1
    PAUSE = 0x2
    STOP = 0x4
    RECORD = 0x8
    FAST_FORWARD = 0x10
    REWIND = 0x20
    NEXT = 0x40
    PREVIOUS = 0x80
    CHANNEL_UP = 0x100
    CHANNEL_DOWN = 0x200

class PlaybackCommand(enum.IntEnum):
    PLAY = 0
    PAUSE = 1
    STOP = 2
    RECORD = 3
    FAST_FORWARD = 4
    REWIND = 5
    NEXT = 6
    PREVIOUS = 7
    CHANNEL_UP = 8
    CHANNEL_DOWN = 9

class PlaybackStatus(enum.IntEnum):
    NONE = 0
    TRACK_CHANGED = 1
    STOPPED = 2
    PLAYING = 3
    PAUSED = 4

class ReminderState(enum.IntEnum):
    ACTIVE = 0
    SNOOZED = 1
    DISMISSED = 2

class VibrateState(enum.IntEnum):
    RINGER_OFF_VIBRATE_OFF = 0
    RINGER_OFF_VIBRATE_ON = 1
    RINGER_ON_VIBRATE_OFF = 2
    RINGER_ON_VIBRATE_ON = 3

_ns_module._register_AccessoryNotificationType(AccessoryNotificationType)
_ns_module._register_CalendarChangedEvent(CalendarChangedEvent)
_ns_module._register_PhoneCallAudioEndpoint(PhoneCallAudioEndpoint)
_ns_module._register_PhoneCallDirection(PhoneCallDirection)
_ns_module._register_PhoneCallState(PhoneCallState)
_ns_module._register_PhoneCallTransport(PhoneCallTransport)
_ns_module._register_PhoneLineRegistrationState(PhoneLineRegistrationState)
_ns_module._register_PhoneMediaType(PhoneMediaType)
_ns_module._register_PhoneNotificationType(PhoneNotificationType)
_ns_module._register_PlaybackCapability(PlaybackCapability)
_ns_module._register_PlaybackCommand(PlaybackCommand)
_ns_module._register_PlaybackStatus(PlaybackStatus)
_ns_module._register_ReminderState(ReminderState)
_ns_module._register_VibrateState(VibrateState)

AccessoryManager = _ns_module.AccessoryManager
AlarmNotificationTriggerDetails = _ns_module.AlarmNotificationTriggerDetails
AppNotificationInfo = _ns_module.AppNotificationInfo
BinaryId = _ns_module.BinaryId
CalendarChangedNotificationTriggerDetails = _ns_module.CalendarChangedNotificationTriggerDetails
CortanaTileNotificationTriggerDetails = _ns_module.CortanaTileNotificationTriggerDetails
EmailAccountInfo = _ns_module.EmailAccountInfo
EmailFolderInfo = _ns_module.EmailFolderInfo
EmailNotificationTriggerDetails = _ns_module.EmailNotificationTriggerDetails
EmailReadNotificationTriggerDetails = _ns_module.EmailReadNotificationTriggerDetails
MediaControlsTriggerDetails = _ns_module.MediaControlsTriggerDetails
MediaMetadata = _ns_module.MediaMetadata
PhoneCallDetails = _ns_module.PhoneCallDetails
PhoneLineDetails = _ns_module.PhoneLineDetails
PhoneNotificationTriggerDetails = _ns_module.PhoneNotificationTriggerDetails
ReminderNotificationTriggerDetails = _ns_module.ReminderNotificationTriggerDetails
SpeedDialEntry = _ns_module.SpeedDialEntry
TextResponse = _ns_module.TextResponse
ToastNotificationTriggerDetails = _ns_module.ToastNotificationTriggerDetails
VolumeInfo = _ns_module.VolumeInfo
IAccessoryNotificationTriggerDetails = _ns_module.IAccessoryNotificationTriggerDetails



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.PointOfService")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics.imaging
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class BarcodeScannerStatus(enum.IntEnum):
    ONLINE = 0
    OFF = 1
    OFFLINE = 2
    OFF_OR_OFFLINE = 3
    EXTENDED = 4

class BarcodeSymbologyDecodeLengthKind(enum.IntEnum):
    ANY_LENGTH = 0
    DISCRETE = 1
    RANGE = 2

class CashDrawerStatusKind(enum.IntEnum):
    ONLINE = 0
    OFF = 1
    OFFLINE = 2
    OFF_OR_OFFLINE = 3
    EXTENDED = 4

class LineDisplayCursorType(enum.IntEnum):
    NONE = 0
    BLOCK = 1
    HALF_BLOCK = 2
    UNDERLINE = 3
    REVERSE = 4
    OTHER = 5

class LineDisplayDescriptorState(enum.IntEnum):
    OFF = 0
    ON = 1
    BLINK = 2

class LineDisplayHorizontalAlignment(enum.IntEnum):
    LEFT = 0
    CENTER = 1
    RIGHT = 2

class LineDisplayMarqueeFormat(enum.IntEnum):
    NONE = 0
    WALK = 1
    PLACE = 2

class LineDisplayPowerStatus(enum.IntEnum):
    UNKNOWN = 0
    ONLINE = 1
    OFF = 2
    OFFLINE = 3
    OFF_OR_OFFLINE = 4

class LineDisplayScrollDirection(enum.IntEnum):
    UP = 0
    DOWN = 1
    LEFT = 2
    RIGHT = 3

class LineDisplayTextAttribute(enum.IntEnum):
    NORMAL = 0
    BLINK = 1
    REVERSE = 2
    REVERSE_BLINK = 3

class LineDisplayTextAttributeGranularity(enum.IntEnum):
    NOT_SUPPORTED = 0
    ENTIRE_DISPLAY = 1
    PER_CHARACTER = 2

class LineDisplayVerticalAlignment(enum.IntEnum):
    TOP = 0
    CENTER = 1
    BOTTOM = 2

class MagneticStripeReaderAuthenticationLevel(enum.IntEnum):
    NOT_SUPPORTED = 0
    OPTIONAL = 1
    REQUIRED = 2

class MagneticStripeReaderAuthenticationProtocol(enum.IntEnum):
    NONE = 0
    CHALLENGE_RESPONSE = 1

class MagneticStripeReaderErrorReportingType(enum.IntEnum):
    CARD_LEVEL = 0
    TRACK_LEVEL = 1

class MagneticStripeReaderStatus(enum.IntEnum):
    UNAUTHENTICATED = 0
    AUTHENTICATED = 1
    EXTENDED = 2

class MagneticStripeReaderTrackErrorType(enum.IntEnum):
    NONE = 0
    START_SENTINEL_ERROR = 1
    END_SENTINEL_ERROR = 2
    PARITY_ERROR = 3
    LRC_ERROR = 4
    UNKNOWN = -1

class MagneticStripeReaderTrackIds(enum.IntEnum):
    NONE = 0
    TRACK1 = 1
    TRACK2 = 2
    TRACK3 = 4
    TRACK4 = 8

class PosConnectionTypes(enum.IntFlag):
    LOCAL = 0x1
    I_P = 0x2
    BLUETOOTH = 0x4
    ALL = 0xffffffff

class PosPrinterAlignment(enum.IntEnum):
    LEFT = 0
    CENTER = 1
    RIGHT = 2

class PosPrinterBarcodeTextPosition(enum.IntEnum):
    NONE = 0
    ABOVE = 1
    BELOW = 2

class PosPrinterCartridgeSensors(enum.IntFlag):
    NONE = 0
    REMOVED = 0x1
    EMPTY = 0x2
    HEAD_CLEANING = 0x4
    NEAR_END = 0x8

class PosPrinterColorCapabilities(enum.IntFlag):
    NONE = 0
    PRIMARY = 0x1
    CUSTOM1 = 0x2
    CUSTOM2 = 0x4
    CUSTOM3 = 0x8
    CUSTOM4 = 0x10
    CUSTOM5 = 0x20
    CUSTOM6 = 0x40
    CYAN = 0x80
    MAGENTA = 0x100
    YELLOW = 0x200
    FULL = 0x400

class PosPrinterColorCartridge(enum.IntEnum):
    UNKNOWN = 0
    PRIMARY = 1
    CUSTOM1 = 2
    CUSTOM2 = 3
    CUSTOM3 = 4
    CUSTOM4 = 5
    CUSTOM5 = 6
    CUSTOM6 = 7
    CYAN = 8
    MAGENTA = 9
    YELLOW = 10

class PosPrinterLineDirection(enum.IntEnum):
    HORIZONTAL = 0
    VERTICAL = 1

class PosPrinterLineStyle(enum.IntEnum):
    SINGLE_SOLID = 0
    DOUBLE_SOLID = 1
    BROKEN = 2
    CHAIN = 3

class PosPrinterMapMode(enum.IntEnum):
    DOTS = 0
    TWIPS = 1
    ENGLISH = 2
    METRIC = 3

class PosPrinterMarkFeedCapabilities(enum.IntFlag):
    NONE = 0
    TO_TAKE_UP = 0x1
    TO_CUTTER = 0x2
    TO_CURRENT_TOP_OF_FORM = 0x4
    TO_NEXT_TOP_OF_FORM = 0x8

class PosPrinterMarkFeedKind(enum.IntEnum):
    TO_TAKE_UP = 0
    TO_CUTTER = 1
    TO_CURRENT_TOP_OF_FORM = 2
    TO_NEXT_TOP_OF_FORM = 3

class PosPrinterPrintSide(enum.IntEnum):
    UNKNOWN = 0
    SIDE1 = 1
    SIDE2 = 2

class PosPrinterRotation(enum.IntEnum):
    NORMAL = 0
    RIGHT90 = 1
    LEFT90 = 2
    ROTATE180 = 3

class PosPrinterRuledLineCapabilities(enum.IntFlag):
    NONE = 0
    HORIZONTAL = 0x1
    VERTICAL = 0x2

class PosPrinterStatusKind(enum.IntEnum):
    ONLINE = 0
    OFF = 1
    OFFLINE = 2
    OFF_OR_OFFLINE = 3
    EXTENDED = 4

class UnifiedPosErrorReason(enum.IntEnum):
    UNKNOWN_ERROR_REASON = 0
    NO_SERVICE = 1
    DISABLED = 2
    ILLEGAL = 3
    NO_HARDWARE = 4
    CLOSED = 5
    OFFLINE = 6
    FAILURE = 7
    TIMEOUT = 8
    BUSY = 9
    EXTENDED = 10

class UnifiedPosErrorSeverity(enum.IntEnum):
    UNKNOWN_ERROR_SEVERITY = 0
    WARNING = 1
    RECOVERABLE = 2
    UNRECOVERABLE = 3
    ASSISTANCE_REQUIRED = 4
    FATAL = 5

class UnifiedPosHealthCheckLevel(enum.IntEnum):
    UNKNOWN_HEALTH_CHECK_LEVEL = 0
    P_O_S_INTERNAL = 1
    EXTERNAL = 2
    INTERACTIVE = 3

class UnifiedPosPowerReportingType(enum.IntEnum):
    UNKNOWN_POWER_REPORTING_TYPE = 0
    STANDARD = 1
    ADVANCED = 2

_ns_module._register_BarcodeScannerStatus(BarcodeScannerStatus)
_ns_module._register_BarcodeSymbologyDecodeLengthKind(BarcodeSymbologyDecodeLengthKind)
_ns_module._register_CashDrawerStatusKind(CashDrawerStatusKind)
_ns_module._register_LineDisplayCursorType(LineDisplayCursorType)
_ns_module._register_LineDisplayDescriptorState(LineDisplayDescriptorState)
_ns_module._register_LineDisplayHorizontalAlignment(LineDisplayHorizontalAlignment)
_ns_module._register_LineDisplayMarqueeFormat(LineDisplayMarqueeFormat)
_ns_module._register_LineDisplayPowerStatus(LineDisplayPowerStatus)
_ns_module._register_LineDisplayScrollDirection(LineDisplayScrollDirection)
_ns_module._register_LineDisplayTextAttribute(LineDisplayTextAttribute)
_ns_module._register_LineDisplayTextAttributeGranularity(LineDisplayTextAttributeGranularity)
_ns_module._register_LineDisplayVerticalAlignment(LineDisplayVerticalAlignment)
_ns_module._register_MagneticStripeReaderAuthenticationLevel(MagneticStripeReaderAuthenticationLevel)
_ns_module._register_MagneticStripeReaderAuthenticationProtocol(MagneticStripeReaderAuthenticationProtocol)
_ns_module._register_MagneticStripeReaderErrorReportingType(MagneticStripeReaderErrorReportingType)
_ns_module._register_MagneticStripeReaderStatus(MagneticStripeReaderStatus)
_ns_module._register_MagneticStripeReaderTrackErrorType(MagneticStripeReaderTrackErrorType)
_ns_module._register_MagneticStripeReaderTrackIds(MagneticStripeReaderTrackIds)
_ns_module._register_PosConnectionTypes(PosConnectionTypes)
_ns_module._register_PosPrinterAlignment(PosPrinterAlignment)
_ns_module._register_PosPrinterBarcodeTextPosition(PosPrinterBarcodeTextPosition)
_ns_module._register_PosPrinterCartridgeSensors(PosPrinterCartridgeSensors)
_ns_module._register_PosPrinterColorCapabilities(PosPrinterColorCapabilities)
_ns_module._register_PosPrinterColorCartridge(PosPrinterColorCartridge)
_ns_module._register_PosPrinterLineDirection(PosPrinterLineDirection)
_ns_module._register_PosPrinterLineStyle(PosPrinterLineStyle)
_ns_module._register_PosPrinterMapMode(PosPrinterMapMode)
_ns_module._register_PosPrinterMarkFeedCapabilities(PosPrinterMarkFeedCapabilities)
_ns_module._register_PosPrinterMarkFeedKind(PosPrinterMarkFeedKind)
_ns_module._register_PosPrinterPrintSide(PosPrinterPrintSide)
_ns_module._register_PosPrinterRotation(PosPrinterRotation)
_ns_module._register_PosPrinterRuledLineCapabilities(PosPrinterRuledLineCapabilities)
_ns_module._register_PosPrinterStatusKind(PosPrinterStatusKind)
_ns_module._register_UnifiedPosErrorReason(UnifiedPosErrorReason)
_ns_module._register_UnifiedPosErrorSeverity(UnifiedPosErrorSeverity)
_ns_module._register_UnifiedPosHealthCheckLevel(UnifiedPosHealthCheckLevel)
_ns_module._register_UnifiedPosPowerReportingType(UnifiedPosPowerReportingType)

SizeUInt32 = _ns_module.SizeUInt32
BarcodeScanner = _ns_module.BarcodeScanner
BarcodeScannerCapabilities = _ns_module.BarcodeScannerCapabilities
BarcodeScannerDataReceivedEventArgs = _ns_module.BarcodeScannerDataReceivedEventArgs
BarcodeScannerErrorOccurredEventArgs = _ns_module.BarcodeScannerErrorOccurredEventArgs
BarcodeScannerImagePreviewReceivedEventArgs = _ns_module.BarcodeScannerImagePreviewReceivedEventArgs
BarcodeScannerReport = _ns_module.BarcodeScannerReport
BarcodeScannerStatusUpdatedEventArgs = _ns_module.BarcodeScannerStatusUpdatedEventArgs
BarcodeSymbologies = _ns_module.BarcodeSymbologies
BarcodeSymbologyAttributes = _ns_module.BarcodeSymbologyAttributes
CashDrawer = _ns_module.CashDrawer
CashDrawerCapabilities = _ns_module.CashDrawerCapabilities
CashDrawerCloseAlarm = _ns_module.CashDrawerCloseAlarm
CashDrawerClosedEventArgs = _ns_module.CashDrawerClosedEventArgs
CashDrawerEventSource = _ns_module.CashDrawerEventSource
CashDrawerOpenedEventArgs = _ns_module.CashDrawerOpenedEventArgs
CashDrawerStatus = _ns_module.CashDrawerStatus
CashDrawerStatusUpdatedEventArgs = _ns_module.CashDrawerStatusUpdatedEventArgs
ClaimedBarcodeScanner = _ns_module.ClaimedBarcodeScanner
ClaimedBarcodeScannerClosedEventArgs = _ns_module.ClaimedBarcodeScannerClosedEventArgs
ClaimedCashDrawer = _ns_module.ClaimedCashDrawer
ClaimedCashDrawerClosedEventArgs = _ns_module.ClaimedCashDrawerClosedEventArgs
ClaimedJournalPrinter = _ns_module.ClaimedJournalPrinter
ClaimedLineDisplay = _ns_module.ClaimedLineDisplay
ClaimedLineDisplayClosedEventArgs = _ns_module.ClaimedLineDisplayClosedEventArgs
ClaimedMagneticStripeReader = _ns_module.ClaimedMagneticStripeReader
ClaimedMagneticStripeReaderClosedEventArgs = _ns_module.ClaimedMagneticStripeReaderClosedEventArgs
ClaimedPosPrinter = _ns_module.ClaimedPosPrinter
ClaimedPosPrinterClosedEventArgs = _ns_module.ClaimedPosPrinterClosedEventArgs
ClaimedReceiptPrinter = _ns_module.ClaimedReceiptPrinter
ClaimedSlipPrinter = _ns_module.ClaimedSlipPrinter
JournalPrintJob = _ns_module.JournalPrintJob
JournalPrinterCapabilities = _ns_module.JournalPrinterCapabilities
LineDisplay = _ns_module.LineDisplay
LineDisplayAttributes = _ns_module.LineDisplayAttributes
LineDisplayCapabilities = _ns_module.LineDisplayCapabilities
LineDisplayCursor = _ns_module.LineDisplayCursor
LineDisplayCursorAttributes = _ns_module.LineDisplayCursorAttributes
LineDisplayCustomGlyphs = _ns_module.LineDisplayCustomGlyphs
LineDisplayMarquee = _ns_module.LineDisplayMarquee
LineDisplayStatisticsCategorySelector = _ns_module.LineDisplayStatisticsCategorySelector
LineDisplayStatusUpdatedEventArgs = _ns_module.LineDisplayStatusUpdatedEventArgs
LineDisplayStoredBitmap = _ns_module.LineDisplayStoredBitmap
LineDisplayWindow = _ns_module.LineDisplayWindow
MagneticStripeReader = _ns_module.MagneticStripeReader
MagneticStripeReaderAamvaCardDataReceivedEventArgs = _ns_module.MagneticStripeReaderAamvaCardDataReceivedEventArgs
MagneticStripeReaderBankCardDataReceivedEventArgs = _ns_module.MagneticStripeReaderBankCardDataReceivedEventArgs
MagneticStripeReaderCapabilities = _ns_module.MagneticStripeReaderCapabilities
MagneticStripeReaderCardTypes = _ns_module.MagneticStripeReaderCardTypes
MagneticStripeReaderEncryptionAlgorithms = _ns_module.MagneticStripeReaderEncryptionAlgorithms
MagneticStripeReaderErrorOccurredEventArgs = _ns_module.MagneticStripeReaderErrorOccurredEventArgs
MagneticStripeReaderReport = _ns_module.MagneticStripeReaderReport
MagneticStripeReaderStatusUpdatedEventArgs = _ns_module.MagneticStripeReaderStatusUpdatedEventArgs
MagneticStripeReaderTrackData = _ns_module.MagneticStripeReaderTrackData
MagneticStripeReaderVendorSpecificCardDataReceivedEventArgs = _ns_module.MagneticStripeReaderVendorSpecificCardDataReceivedEventArgs
PosPrinter = _ns_module.PosPrinter
PosPrinterCapabilities = _ns_module.PosPrinterCapabilities
PosPrinterCharacterSetIds = _ns_module.PosPrinterCharacterSetIds
PosPrinterFontProperty = _ns_module.PosPrinterFontProperty
PosPrinterPrintOptions = _ns_module.PosPrinterPrintOptions
PosPrinterReleaseDeviceRequestedEventArgs = _ns_module.PosPrinterReleaseDeviceRequestedEventArgs
PosPrinterStatus = _ns_module.PosPrinterStatus
PosPrinterStatusUpdatedEventArgs = _ns_module.PosPrinterStatusUpdatedEventArgs
ReceiptPrintJob = _ns_module.ReceiptPrintJob
ReceiptPrinterCapabilities = _ns_module.ReceiptPrinterCapabilities
SlipPrintJob = _ns_module.SlipPrintJob
SlipPrinterCapabilities = _ns_module.SlipPrinterCapabilities
UnifiedPosErrorData = _ns_module.UnifiedPosErrorData
ICashDrawerEventSourceEventArgs = _ns_module.ICashDrawerEventSourceEventArgs
ICommonClaimedPosPrinterStation = _ns_module.ICommonClaimedPosPrinterStation
ICommonPosPrintStationCapabilities = _ns_module.ICommonPosPrintStationCapabilities
ICommonReceiptSlipCapabilities = _ns_module.ICommonReceiptSlipCapabilities
IPosPrinterJob = _ns_module.IPosPrinterJob
IReceiptOrSlipJob = _ns_module.IReceiptOrSlipJob



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.AppRecording")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class AppRecordingSaveScreenshotOption(enum.IntEnum):
    NONE = 0
    HDR_CONTENT_VISIBLE = 1

_ns_module._register_AppRecordingSaveScreenshotOption(AppRecordingSaveScreenshotOption)

AppRecordingManager = _ns_module.AppRecordingManager
AppRecordingResult = _ns_module.AppRecordingResult
AppRecordingSaveScreenshotResult = _ns_module.AppRecordingSaveScreenshotResult
AppRecordingSavedScreenshotInfo = _ns_module.AppRecordingSavedScreenshotInfo
AppRecordingStatus = _ns_module.AppRecordingStatus
AppRecordingStatusDetails = _ns_module.AppRecordingStatusDetails



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.ExtendedExecution")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class ExtendedExecutionReason(enum.IntEnum):
    UNSPECIFIED = 0
    LOCATION_TRACKING = 1
    SAVING_DATA = 2

class ExtendedExecutionResult(enum.IntEnum):
    ALLOWED = 0
    DENIED = 1

class ExtendedExecutionRevokedReason(enum.IntEnum):
    RESUMED = 0
    SYSTEM_POLICY = 1

_ns_module._register_ExtendedExecutionReason(ExtendedExecutionReason)
_ns_module._register_ExtendedExecutionResult(ExtendedExecutionResult)
_ns_module._register_ExtendedExecutionRevokedReason(ExtendedExecutionRevokedReason)

ExtendedExecutionRevokedEventArgs = _ns_module.ExtendedExecutionRevokedEventArgs
ExtendedExecutionSession = _ns_module.ExtendedExecutionSession



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel
import winsdk.windows.applicationmodel.activation
import winsdk.windows.applicationmodel.appointments.appointmentsprovider
import winsdk.windows.applicationmodel.background
import winsdk.windows.applicationmodel.calls
import winsdk.windows.applicationmodel.contacts
import winsdk.windows.applicationmodel.contacts.provider
import winsdk.windows.applicationmodel.core
import winsdk.windows.applicationmodel.datatransfer
import winsdk.windows.applicationmodel.datatransfer.sharetarget
import winsdk.windows.applicationmodel.search
import winsdk.windows.applicationmodel.userdataaccounts.provider
import winsdk.windows.applicationmodel.wallet
import winsdk.windows.devices.enumeration
import winsdk.windows.devices.printers.extensions
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.media.speechrecognition
import winsdk.windows.security.authentication.web
import winsdk.windows.security.authentication.web.provider
import winsdk.windows.storage
import winsdk.windows.storage.pickers.provider
import winsdk.windows.storage.provider
import winsdk.windows.storage.search
import winsdk.windows.storage.streams
import winsdk.windows.system
import winsdk.windows.ui
import winsdk.windows.web
import winsdk.windows.web.http
import winsdk.windows.web.ui

class PrintContent(enum.IntEnum):
    ALL_PAGES = 0
    CURRENT_PAGE = 1
    CUSTOM_PAGE_RANGE = 2
    CURRENT_SELECTION = 3

Self = typing.TypeVar('Self')

class ActivatedDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ActivatedDeferral: ...
    def complete(self) -> None: ...

class ActivatedOperation(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ActivatedOperation: ...
    def get_deferral(self) -> typing.Optional[ActivatedDeferral]: ...

class BackgroundActivatedEventArgs(winsdk.system.Object):
    task_instance: typing.Optional[winsdk.windows.applicationmodel.background.IBackgroundTaskInstance]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BackgroundActivatedEventArgs: ...

class EnteredBackgroundEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnteredBackgroundEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class HtmlPrintDocumentSource(winsdk.system.Object):
    top_margin: winsdk.system.Single
    shrink_to_fit: winsdk.system.Boolean
    right_margin: winsdk.system.Single
    percent_scale: winsdk.system.Single
    left_margin: winsdk.system.Single
    enable_header_footer: winsdk.system.Boolean
    content: PrintContent
    bottom_margin: winsdk.system.Single
    page_range: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HtmlPrintDocumentSource: ...
    def close(self) -> None: ...
    def try_set_page_range(self, str_page_range: str) -> winsdk.system.Boolean: ...

class LeavingBackgroundEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LeavingBackgroundEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class NewWebUIViewCreatedEventArgs(winsdk.system.Object):
    activated_event_args: typing.Optional[winsdk.windows.applicationmodel.activation.IActivatedEventArgs]
    has_pending_navigate: winsdk.system.Boolean
    web_u_i_view: typing.Optional[WebUIView]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> NewWebUIViewCreatedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class SuspendingDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SuspendingDeferral: ...
    def complete(self) -> None: ...

class SuspendingEventArgs(winsdk.system.Object):
    suspending_operation: typing.Optional[winsdk.windows.applicationmodel.SuspendingOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SuspendingEventArgs: ...

class SuspendingOperation(winsdk.system.Object):
    deadline: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SuspendingOperation: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.applicationmodel.SuspendingDeferral]: ...

class WebUIApplication(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIApplication: ...
    @staticmethod
    def enable_prelaunch(value: winsdk.system.Boolean) -> None: ...
    @staticmethod
    def request_restart_async(launch_arguments: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.applicationmodel.core.AppRestartFailureReason]: ...
    @staticmethod
    def request_restart_for_user_async(user: typing.Optional[winsdk.windows.system.User], launch_arguments: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.applicationmodel.core.AppRestartFailureReason]: ...
    @staticmethod
    def add_background_activated(handler: typing.Optional[BackgroundActivatedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_background_activated(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_new_web_u_i_view_created(handler: winsdk.windows.foundation.EventHandler[NewWebUIViewCreatedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_new_web_u_i_view_created(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_entered_background(handler: typing.Optional[EnteredBackgroundEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_entered_background(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_leaving_background(handler: typing.Optional[LeavingBackgroundEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_leaving_background(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_activated(handler: typing.Optional[ActivatedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_activated(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_navigated(handler: typing.Optional[NavigatedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_navigated(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_resuming(handler: typing.Optional[ResumingEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_resuming(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_suspending(handler: typing.Optional[SuspendingEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_suspending(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebUIAppointmentsProviderAddAppointmentActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    verb: str
    add_appointment_operation: typing.Optional[winsdk.windows.applicationmodel.appointments.appointmentsprovider.AddAppointmentOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIAppointmentsProviderAddAppointmentActivatedEventArgs: ...

class WebUIAppointmentsProviderRemoveAppointmentActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    verb: str
    remove_appointment_operation: typing.Optional[winsdk.windows.applicationmodel.appointments.appointmentsprovider.RemoveAppointmentOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIAppointmentsProviderRemoveAppointmentActivatedEventArgs: ...

class WebUIAppointmentsProviderReplaceAppointmentActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    verb: str
    replace_appointment_operation: typing.Optional[winsdk.windows.applicationmodel.appointments.appointmentsprovider.ReplaceAppointmentOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIAppointmentsProviderReplaceAppointmentActivatedEventArgs: ...

class WebUIAppointmentsProviderShowAppointmentDetailsActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    verb: str
    instance_start_date: typing.Optional[typing.Optional[datetime.datetime]]
    local_id: str
    roaming_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIAppointmentsProviderShowAppointmentDetailsActivatedEventArgs: ...

class WebUIAppointmentsProviderShowTimeFrameActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    verb: str
    duration: datetime.timedelta
    time_to_show: datetime.datetime
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIAppointmentsProviderShowTimeFrameActivatedEventArgs: ...

class WebUIBackgroundTaskInstance(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[IWebUIBackgroundTaskInstance]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIBackgroundTaskInstance: ...

class WebUIBackgroundTaskInstanceRuntimeClass(winsdk.system.Object):
    progress: winsdk.system.UInt32
    instance_id: winsdk.system.Guid
    suspended_count: winsdk.system.UInt32
    task: typing.Optional[winsdk.windows.applicationmodel.background.BackgroundTaskRegistration]
    trigger_details: typing.Optional[winsdk.system.Object]
    succeeded: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIBackgroundTaskInstanceRuntimeClass: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.applicationmodel.background.BackgroundTaskDeferral]: ...
    def add_canceled(self, cancel_handler: typing.Optional[winsdk.windows.applicationmodel.background.BackgroundTaskCanceledEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_canceled(self, cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebUIBarcodeScannerPreviewActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    connection_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIBarcodeScannerPreviewActivatedEventArgs: ...

class WebUICachedFileUpdaterActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    cached_file_updater_u_i: typing.Optional[winsdk.windows.storage.provider.CachedFileUpdaterUI]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICachedFileUpdaterActivatedEventArgs: ...

class WebUICameraSettingsActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    video_device_controller: typing.Optional[winsdk.system.Object]
    video_device_extension: typing.Optional[winsdk.system.Object]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICameraSettingsActivatedEventArgs: ...

class WebUICommandLineActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    operation: typing.Optional[winsdk.windows.applicationmodel.activation.CommandLineActivationOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUICommandLineActivatedEventArgs: ...

class WebUIContactCallActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    verb: str
    contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]
    service_id: str
    service_user_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIContactCallActivatedEventArgs: ...

class WebUIContactMapActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    verb: str
    address: typing.Optional[winsdk.windows.applicationmodel.contacts.ContactAddress]
    contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIContactMapActivatedEventArgs: ...

class WebUIContactMessageActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    verb: str
    contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]
    service_id: str
    service_user_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIContactMessageActivatedEventArgs: ...

class WebUIContactPanelActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]
    contact_panel: typing.Optional[winsdk.windows.applicationmodel.contacts.ContactPanel]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIContactPanelActivatedEventArgs: ...

class WebUIContactPickerActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    contact_picker_u_i: typing.Optional[winsdk.windows.applicationmodel.contacts.provider.ContactPickerUI]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIContactPickerActivatedEventArgs: ...

class WebUIContactPostActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    verb: str
    contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]
    service_id: str
    service_user_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIContactPostActivatedEventArgs: ...

class WebUIContactVideoCallActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    verb: str
    contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]
    service_id: str
    service_user_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIContactVideoCallActivatedEventArgs: ...

class WebUIDeviceActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    currently_shown_application_view_id: winsdk.system.Int32
    device_information_id: str
    verb: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIDeviceActivatedEventArgs: ...

class WebUIDevicePairingActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    device_information: typing.Optional[winsdk.windows.devices.enumeration.DeviceInformation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIDevicePairingActivatedEventArgs: ...

class WebUIDialReceiverActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    currently_shown_application_view_id: winsdk.system.Int32
    app_name: str
    arguments: str
    tile_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIDialReceiverActivatedEventArgs: ...

class WebUIFileActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    currently_shown_application_view_id: winsdk.system.Int32
    files: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.storage.IStorageItem]]
    verb: str
    neighboring_files_query: typing.Optional[winsdk.windows.storage.search.StorageFileQueryResult]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIFileActivatedEventArgs: ...

class WebUIFileOpenPickerActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    file_open_picker_u_i: typing.Optional[winsdk.windows.storage.pickers.provider.FileOpenPickerUI]
    caller_package_family_name: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIFileOpenPickerActivatedEventArgs: ...

class WebUIFileOpenPickerContinuationEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    continuation_data: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    files: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.storage.StorageFile]]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIFileOpenPickerContinuationEventArgs: ...

class WebUIFileSavePickerActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    file_save_picker_u_i: typing.Optional[winsdk.windows.storage.pickers.provider.FileSavePickerUI]
    caller_package_family_name: str
    enterprise_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIFileSavePickerActivatedEventArgs: ...

class WebUIFileSavePickerContinuationEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    continuation_data: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    file: typing.Optional[winsdk.windows.storage.StorageFile]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIFileSavePickerContinuationEventArgs: ...

class WebUIFolderPickerContinuationEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    continuation_data: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    folder: typing.Optional[winsdk.windows.storage.StorageFolder]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIFolderPickerContinuationEventArgs: ...

class WebUILaunchActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    currently_shown_application_view_id: winsdk.system.Int32
    arguments: str
    tile_id: str
    tile_activated_info: typing.Optional[winsdk.windows.applicationmodel.activation.TileActivatedInfo]
    prelaunch_activated: winsdk.system.Boolean
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUILaunchActivatedEventArgs: ...

class WebUILockScreenActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    currently_shown_application_view_id: winsdk.system.Int32
    info: typing.Optional[winsdk.system.Object]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUILockScreenActivatedEventArgs: ...

class WebUILockScreenCallActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    currently_shown_application_view_id: winsdk.system.Int32
    arguments: str
    tile_id: str
    call_u_i: typing.Optional[winsdk.windows.applicationmodel.calls.LockScreenCallUI]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUILockScreenCallActivatedEventArgs: ...

class WebUILockScreenComponentActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUILockScreenComponentActivatedEventArgs: ...

class WebUINavigatedDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUINavigatedDeferral: ...
    def complete(self) -> None: ...

class WebUINavigatedEventArgs(winsdk.system.Object):
    navigated_operation: typing.Optional[WebUINavigatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUINavigatedEventArgs: ...

class WebUINavigatedOperation(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUINavigatedOperation: ...
    def get_deferral(self) -> typing.Optional[WebUINavigatedDeferral]: ...

class WebUIPhoneCallActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    line_id: winsdk.system.Guid
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIPhoneCallActivatedEventArgs: ...

class WebUIPrint3DWorkflowActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    workflow: typing.Optional[winsdk.windows.devices.printers.extensions.Print3DWorkflow]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIPrint3DWorkflowActivatedEventArgs: ...

class WebUIPrintTaskSettingsActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    configuration: typing.Optional[winsdk.windows.devices.printers.extensions.PrintTaskConfiguration]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIPrintTaskSettingsActivatedEventArgs: ...

class WebUIPrintWorkflowForegroundTaskActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIPrintWorkflowForegroundTaskActivatedEventArgs: ...

class WebUIProtocolActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    currently_shown_application_view_id: winsdk.system.Int32
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    caller_package_family_name: str
    data: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIProtocolActivatedEventArgs: ...

class WebUIProtocolForResultsActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    currently_shown_application_view_id: winsdk.system.Int32
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    caller_package_family_name: str
    data: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    protocol_for_results_operation: typing.Optional[winsdk.windows.system.ProtocolForResultsOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIProtocolForResultsActivatedEventArgs: ...

class WebUIRestrictedLaunchActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    shared_context: typing.Optional[winsdk.system.Object]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIRestrictedLaunchActivatedEventArgs: ...

class WebUISearchActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    currently_shown_application_view_id: winsdk.system.Int32
    language: str
    query_text: str
    linguistic_details: typing.Optional[winsdk.windows.applicationmodel.search.SearchPaneQueryLinguisticDetails]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUISearchActivatedEventArgs: ...

class WebUIShareTargetActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    share_operation: typing.Optional[winsdk.windows.applicationmodel.datatransfer.sharetarget.ShareOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIShareTargetActivatedEventArgs: ...

class WebUIStartupTaskActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    task_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIStartupTaskActivatedEventArgs: ...

class WebUIToastNotificationActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    argument: str
    user_input: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIToastNotificationActivatedEventArgs: ...

class WebUIUserDataAccountProviderActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    operation: typing.Optional[winsdk.windows.applicationmodel.userdataaccounts.provider.IUserDataAccountProviderOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIUserDataAccountProviderActivatedEventArgs: ...

class WebUIView(winsdk.system.Object):
    ignore_application_content_uri_rules_navigation_restrictions: winsdk.system.Boolean
    application_view_id: winsdk.system.Int32
    source: typing.Optional[winsdk.windows.foundation.Uri]
    default_background_color: winsdk.windows.ui.Color
    can_go_back: winsdk.system.Boolean
    can_go_forward: winsdk.system.Boolean
    contains_full_screen_element: winsdk.system.Boolean
    deferred_permission_requests: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.web.ui.WebViewControlDeferredPermissionRequest]]
    document_title: str
    settings: typing.Optional[winsdk.windows.web.ui.WebViewControlSettings]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIView: ...
    def add_initialize_script(self, script: str) -> None: ...
    def build_local_stream_uri(self, content_identifier: str, relative_path: str) -> typing.Optional[winsdk.windows.foundation.Uri]: ...
    def capture_preview_to_stream_async(self, stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    def capture_selected_content_to_data_package_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.applicationmodel.datatransfer.DataPackage]: ...
    @typing.overload
    @staticmethod
    def create_async() -> winsdk.windows.foundation.IAsyncOperation[WebUIView]: ...
    @typing.overload
    @staticmethod
    def create_async(uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[WebUIView]: ...
    def get_deferred_permission_request_by_id(self, id: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.web.ui.WebViewControlDeferredPermissionRequest]: ...
    def go_back(self) -> None: ...
    def go_forward(self) -> None: ...
    def invoke_script_async(self, script_name: str, arguments: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def navigate(self, source: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    def navigate_to_local_stream_uri(self, source: typing.Optional[winsdk.windows.foundation.Uri], stream_resolver: typing.Optional[winsdk.windows.web.IUriToStreamResolver]) -> None: ...
    def navigate_to_string(self, text: str) -> None: ...
    def navigate_with_http_request_message(self, request_message: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]) -> None: ...
    def refresh(self) -> None: ...
    def stop(self) -> None: ...
    def add_activated(self, handler: winsdk.windows.foundation.TypedEventHandler[WebUIView, winsdk.windows.applicationmodel.activation.IActivatedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_activated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_closed(self, handler: winsdk.windows.foundation.TypedEventHandler[WebUIView, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_contains_full_screen_element_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_contains_full_screen_element_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_content_loading(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlContentLoadingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_content_loading(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_d_o_m_content_loaded(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlDOMContentLoadedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_d_o_m_content_loaded(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_content_loading(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlContentLoadingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_content_loading(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_d_o_m_content_loaded(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlDOMContentLoadedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_d_o_m_content_loaded(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_navigation_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_navigation_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_navigation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_navigation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_long_running_script_detected(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlLongRunningScriptDetectedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_long_running_script_detected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_navigation_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_navigation_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_navigation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNavigationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_navigation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_new_window_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlNewWindowRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_new_window_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_permission_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlPermissionRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_permission_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_script_notify(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlScriptNotifyEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_script_notify(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unsafe_content_warning_displaying(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unsafe_content_warning_displaying(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unsupported_uri_scheme_identified(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlUnsupportedUriSchemeIdentifiedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unsupported_uri_scheme_identified(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unviewable_content_identified(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlUnviewableContentIdentifiedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unviewable_content_identified(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_web_resource_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.windows.web.ui.IWebViewControl, winsdk.windows.web.ui.WebViewControlWebResourceRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_web_resource_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebUIVoiceCommandActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    result: typing.Optional[winsdk.windows.media.speechrecognition.SpeechRecognitionResult]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIVoiceCommandActivatedEventArgs: ...

class WebUIWalletActionActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    action_id: str
    action_kind: winsdk.windows.applicationmodel.wallet.WalletActionKind
    item_id: str
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIWalletActionActivatedEventArgs: ...

class WebUIWebAccountProviderActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    operation: typing.Optional[winsdk.windows.security.authentication.web.provider.IWebAccountProviderOperation]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIWebAccountProviderActivatedEventArgs: ...

class WebUIWebAuthenticationBrokerContinuationEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    continuation_data: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    web_authentication_result: typing.Optional[winsdk.windows.security.authentication.web.WebAuthenticationResult]
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebUIWebAuthenticationBrokerContinuationEventArgs: ...

class IActivatedEventArgsDeferral(winsdk.system.Object):
    activated_operation: typing.Optional[ActivatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IActivatedEventArgsDeferral: ...

class IWebUIBackgroundTaskInstance(winsdk.system.Object):
    succeeded: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebUIBackgroundTaskInstance: ...

class IWebUINavigatedEventArgs(winsdk.system.Object):
    navigated_operation: typing.Optional[WebUINavigatedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebUINavigatedEventArgs: ...

ActivatedEventHandler = typing.Callable[[typing.Optional[winsdk.system.Object], typing.Optional[winsdk.windows.applicationmodel.activation.IActivatedEventArgs]], None]

BackgroundActivatedEventHandler = typing.Callable[[typing.Optional[winsdk.system.Object], typing.Optional[winsdk.windows.applicationmodel.activation.IBackgroundActivatedEventArgs]], None]

EnteredBackgroundEventHandler = typing.Callable[[typing.Optional[winsdk.system.Object], typing.Optional[winsdk.windows.applicationmodel.IEnteredBackgroundEventArgs]], None]

LeavingBackgroundEventHandler = typing.Callable[[typing.Optional[winsdk.system.Object], typing.Optional[winsdk.windows.applicationmodel.ILeavingBackgroundEventArgs]], None]

NavigatedEventHandler = typing.Callable[[typing.Optional[winsdk.system.Object], typing.Optional[IWebUINavigatedEventArgs]], None]

ResumingEventHandler = typing.Callable[[typing.Optional[winsdk.system.Object]], None]

SuspendingEventHandler = typing.Callable[[typing.Optional[winsdk.system.Object], typing.Optional[winsdk.windows.applicationmodel.ISuspendingEventArgs]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Calls.Background")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class PhoneCallBlockedReason(enum.IntEnum):
    IN_CALL_BLOCKING_LIST = 0
    PRIVATE_NUMBER = 1
    UNKNOWN_NUMBER = 2

class PhoneIncomingCallDismissedReason(enum.IntEnum):
    UNKNOWN = 0
    CALL_REJECTED = 1
    TEXT_REPLY = 2
    CONNECTION_LOST = 3

class PhoneLineChangeKind(enum.IntEnum):
    ADDED = 0
    REMOVED = 1
    PROPERTIES_CHANGED = 2

class PhoneLineProperties(enum.IntFlag):
    NONE = 0
    BRANDING_OPTIONS = 0x1
    CAN_DIAL = 0x2
    CELLULAR_DETAILS = 0x4
    DISPLAY_COLOR = 0x8
    DISPLAY_NAME = 0x10
    NETWORK_NAME = 0x20
    NETWORK_STATE = 0x40
    TRANSPORT = 0x80
    VOICEMAIL = 0x100

class PhoneTriggerType(enum.IntEnum):
    NEW_VOICEMAIL_MESSAGE = 0
    CALL_HISTORY_CHANGED = 1
    LINE_CHANGED = 2
    AIRPLANE_MODE_DISABLED_FOR_EMERGENCY_CALL = 3
    CALL_ORIGIN_DATA_REQUEST = 4
    CALL_BLOCKED = 5
    INCOMING_CALL_DISMISSED = 6
    INCOMING_CALL_NOTIFICATION = 7

_ns_module._register_PhoneCallBlockedReason(PhoneCallBlockedReason)
_ns_module._register_PhoneIncomingCallDismissedReason(PhoneIncomingCallDismissedReason)
_ns_module._register_PhoneLineChangeKind(PhoneLineChangeKind)
_ns_module._register_PhoneLineProperties(PhoneLineProperties)
_ns_module._register_PhoneTriggerType(PhoneTriggerType)

PhoneCallBlockedTriggerDetails = _ns_module.PhoneCallBlockedTriggerDetails
PhoneCallOriginDataRequestTriggerDetails = _ns_module.PhoneCallOriginDataRequestTriggerDetails
PhoneIncomingCallDismissedTriggerDetails = _ns_module.PhoneIncomingCallDismissedTriggerDetails
PhoneIncomingCallNotificationTriggerDetails = _ns_module.PhoneIncomingCallNotificationTriggerDetails
PhoneLineChangedTriggerDetails = _ns_module.PhoneLineChangedTriggerDetails
PhoneNewVoicemailMessageTriggerDetails = _ns_module.PhoneNewVoicemailMessageTriggerDetails



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Graphics.Printing")

try:
    import winsdk.windows.applicationmodel.datatransfer
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class PrintBinding(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    NONE = 3
    BALE = 4
    BIND_BOTTOM = 5
    BIND_LEFT = 6
    BIND_RIGHT = 7
    BIND_TOP = 8
    BOOKLET = 9
    EDGE_STITCH_BOTTOM = 10
    EDGE_STITCH_LEFT = 11
    EDGE_STITCH_RIGHT = 12
    EDGE_STITCH_TOP = 13
    FOLD = 14
    JOG_OFFSET = 15
    TRIM = 16

class PrintBordering(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    BORDERED = 3
    BORDERLESS = 4

class PrintCollation(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    COLLATED = 3
    UNCOLLATED = 4

class PrintColorMode(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    COLOR = 3
    GRAYSCALE = 4
    MONOCHROME = 5

class PrintDuplex(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    ONE_SIDED = 3
    TWO_SIDED_SHORT_EDGE = 4
    TWO_SIDED_LONG_EDGE = 5

class PrintHolePunch(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    NONE = 3
    LEFT_EDGE = 4
    RIGHT_EDGE = 5
    TOP_EDGE = 6
    BOTTOM_EDGE = 7

class PrintMediaSize(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    BUSINESS_CARD = 3
    CREDIT_CARD = 4
    ISO_A0 = 5
    ISO_A1 = 6
    ISO_A10 = 7
    ISO_A2 = 8
    ISO_A3 = 9
    ISO_A3_EXTRA = 10
    ISO_A3_ROTATED = 11
    ISO_A4 = 12
    ISO_A4_EXTRA = 13
    ISO_A4_ROTATED = 14
    ISO_A5 = 15
    ISO_A5_EXTRA = 16
    ISO_A5_ROTATED = 17
    ISO_A6 = 18
    ISO_A6_ROTATED = 19
    ISO_A7 = 20
    ISO_A8 = 21
    ISO_A9 = 22
    ISO_B0 = 23
    ISO_B1 = 24
    ISO_B10 = 25
    ISO_B2 = 26
    ISO_B3 = 27
    ISO_B4 = 28
    ISO_B4_ENVELOPE = 29
    ISO_B5_ENVELOPE = 30
    ISO_B5_EXTRA = 31
    ISO_B7 = 32
    ISO_B8 = 33
    ISO_B9 = 34
    ISO_C0 = 35
    ISO_C1 = 36
    ISO_C10 = 37
    ISO_C2 = 38
    ISO_C3 = 39
    ISO_C3_ENVELOPE = 40
    ISO_C4 = 41
    ISO_C4_ENVELOPE = 42
    ISO_C5 = 43
    ISO_C5_ENVELOPE = 44
    ISO_C6 = 45
    ISO_C6_C5_ENVELOPE = 46
    ISO_C6_ENVELOPE = 47
    ISO_C7 = 48
    ISO_C8 = 49
    ISO_C9 = 50
    ISO_D_L_ENVELOPE = 51
    ISO_D_L_ENVELOPE_ROTATED = 52
    ISO_S_R_A3 = 53
    JAPAN2_L_PHOTO = 54
    JAPAN_CHOU3_ENVELOPE = 55
    JAPAN_CHOU3_ENVELOPE_ROTATED = 56
    JAPAN_CHOU4_ENVELOPE = 57
    JAPAN_CHOU4_ENVELOPE_ROTATED = 58
    JAPAN_DOUBLE_HAGAKI_POSTCARD = 59
    JAPAN_DOUBLE_HAGAKI_POSTCARD_ROTATED = 60
    JAPAN_HAGAKI_POSTCARD = 61
    JAPAN_HAGAKI_POSTCARD_ROTATED = 62
    JAPAN_KAKU2_ENVELOPE = 63
    JAPAN_KAKU2_ENVELOPE_ROTATED = 64
    JAPAN_KAKU3_ENVELOPE = 65
    JAPAN_KAKU3_ENVELOPE_ROTATED = 66
    JAPAN_L_PHOTO = 67
    JAPAN_QUADRUPLE_HAGAKI_POSTCARD = 68
    JAPAN_YOU1_ENVELOPE = 69
    JAPAN_YOU2_ENVELOPE = 70
    JAPAN_YOU3_ENVELOPE = 71
    JAPAN_YOU4_ENVELOPE = 72
    JAPAN_YOU4_ENVELOPE_ROTATED = 73
    JAPAN_YOU6_ENVELOPE = 74
    JAPAN_YOU6_ENVELOPE_ROTATED = 75
    JIS_B0 = 76
    JIS_B1 = 77
    JIS_B10 = 78
    JIS_B2 = 79
    JIS_B3 = 80
    JIS_B4 = 81
    JIS_B4_ROTATED = 82
    JIS_B5 = 83
    JIS_B5_ROTATED = 84
    JIS_B6 = 85
    JIS_B6_ROTATED = 86
    JIS_B7 = 87
    JIS_B8 = 88
    JIS_B9 = 89
    NORTH_AMERICA10X11 = 90
    NORTH_AMERICA10X12 = 91
    NORTH_AMERICA10X14 = 92
    NORTH_AMERICA11X17 = 93
    NORTH_AMERICA14X17 = 94
    NORTH_AMERICA4X6 = 95
    NORTH_AMERICA4X8 = 96
    NORTH_AMERICA5X7 = 97
    NORTH_AMERICA8X10 = 98
    NORTH_AMERICA9X11 = 99
    NORTH_AMERICA_ARCHITECTURE_A_SHEET = 100
    NORTH_AMERICA_ARCHITECTURE_B_SHEET = 101
    NORTH_AMERICA_ARCHITECTURE_C_SHEET = 102
    NORTH_AMERICA_ARCHITECTURE_D_SHEET = 103
    NORTH_AMERICA_ARCHITECTURE_E_SHEET = 104
    NORTH_AMERICA_C_SHEET = 105
    NORTH_AMERICA_D_SHEET = 106
    NORTH_AMERICA_E_SHEET = 107
    NORTH_AMERICA_EXECUTIVE = 108
    NORTH_AMERICA_GERMAN_LEGAL_FANFOLD = 109
    NORTH_AMERICA_GERMAN_STANDARD_FANFOLD = 110
    NORTH_AMERICA_LEGAL = 111
    NORTH_AMERICA_LEGAL_EXTRA = 112
    NORTH_AMERICA_LETTER = 113
    NORTH_AMERICA_LETTER_EXTRA = 114
    NORTH_AMERICA_LETTER_PLUS = 115
    NORTH_AMERICA_LETTER_ROTATED = 116
    NORTH_AMERICA_MONARCH_ENVELOPE = 117
    NORTH_AMERICA_NOTE = 118
    NORTH_AMERICA_NUMBER10_ENVELOPE = 119
    NORTH_AMERICA_NUMBER10_ENVELOPE_ROTATED = 120
    NORTH_AMERICA_NUMBER11_ENVELOPE = 121
    NORTH_AMERICA_NUMBER12_ENVELOPE = 122
    NORTH_AMERICA_NUMBER14_ENVELOPE = 123
    NORTH_AMERICA_NUMBER9_ENVELOPE = 124
    NORTH_AMERICA_PERSONAL_ENVELOPE = 125
    NORTH_AMERICA_QUARTO = 126
    NORTH_AMERICA_STATEMENT = 127
    NORTH_AMERICA_SUPER_A = 128
    NORTH_AMERICA_SUPER_B = 129
    NORTH_AMERICA_TABLOID = 130
    NORTH_AMERICA_TABLOID_EXTRA = 131
    OTHER_METRIC_A3_PLUS = 132
    OTHER_METRIC_A4_PLUS = 133
    OTHER_METRIC_FOLIO = 134
    OTHER_METRIC_INVITE_ENVELOPE = 135
    OTHER_METRIC_ITALIAN_ENVELOPE = 136
    PRC10_ENVELOPE = 137
    PRC10_ENVELOPE_ROTATED = 138
    PRC16_K = 139
    PRC16_K_ROTATED = 140
    PRC1_ENVELOPE = 141
    PRC1_ENVELOPE_ROTATED = 142
    PRC2_ENVELOPE = 143
    PRC2_ENVELOPE_ROTATED = 144
    PRC32_K = 145
    PRC32_K_BIG = 146
    PRC32_K_ROTATED = 147
    PRC3_ENVELOPE = 148
    PRC3_ENVELOPE_ROTATED = 149
    PRC4_ENVELOPE = 150
    PRC4_ENVELOPE_ROTATED = 151
    PRC5_ENVELOPE = 152
    PRC5_ENVELOPE_ROTATED = 153
    PRC6_ENVELOPE = 154
    PRC6_ENVELOPE_ROTATED = 155
    PRC7_ENVELOPE = 156
    PRC7_ENVELOPE_ROTATED = 157
    PRC8_ENVELOPE = 158
    PRC8_ENVELOPE_ROTATED = 159
    PRC9_ENVELOPE = 160
    PRC9_ENVELOPE_ROTATED = 161
    ROLL04_INCH = 162
    ROLL06_INCH = 163
    ROLL08_INCH = 164
    ROLL12_INCH = 165
    ROLL15_INCH = 166
    ROLL18_INCH = 167
    ROLL22_INCH = 168
    ROLL24_INCH = 169
    ROLL30_INCH = 170
    ROLL36_INCH = 171
    ROLL54_INCH = 172

class PrintMediaType(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    AUTO_SELECT = 3
    ARCHIVAL = 4
    BACK_PRINT_FILM = 5
    BOND = 6
    CARD_STOCK = 7
    CONTINUOUS = 8
    ENVELOPE_PLAIN = 9
    ENVELOPE_WINDOW = 10
    FABRIC = 11
    HIGH_RESOLUTION = 12
    LABEL = 13
    MULTI_LAYER_FORM = 14
    MULTI_PART_FORM = 15
    PHOTOGRAPHIC = 16
    PHOTOGRAPHIC_FILM = 17
    PHOTOGRAPHIC_GLOSSY = 18
    PHOTOGRAPHIC_HIGH_GLOSS = 19
    PHOTOGRAPHIC_MATTE = 20
    PHOTOGRAPHIC_SATIN = 21
    PHOTOGRAPHIC_SEMI_GLOSS = 22
    PLAIN = 23
    SCREEN = 24
    SCREEN_PAGED = 25
    STATIONERY = 26
    TAB_STOCK_FULL = 27
    TAB_STOCK_PRE_CUT = 28
    TRANSPARENCY = 29
    T_SHIRT_TRANSFER = 30
    NONE = 31

class PrintOrientation(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    PORTRAIT = 3
    PORTRAIT_FLIPPED = 4
    LANDSCAPE = 5
    LANDSCAPE_FLIPPED = 6

class PrintQuality(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    AUTOMATIC = 3
    DRAFT = 4
    FAX = 5
    HIGH = 6
    NORMAL = 7
    PHOTOGRAPHIC = 8
    TEXT = 9

class PrintStaple(enum.IntEnum):
    DEFAULT = 0
    NOT_AVAILABLE = 1
    PRINTER_CUSTOM = 2
    NONE = 3
    STAPLE_TOP_LEFT = 4
    STAPLE_TOP_RIGHT = 5
    STAPLE_BOTTOM_LEFT = 6
    STAPLE_BOTTOM_RIGHT = 7
    STAPLE_DUAL_LEFT = 8
    STAPLE_DUAL_RIGHT = 9
    STAPLE_DUAL_TOP = 10
    STAPLE_DUAL_BOTTOM = 11
    SADDLE_STITCH = 12

class PrintTaskCompletion(enum.IntEnum):
    ABANDONED = 0
    CANCELED = 1
    FAILED = 2
    SUBMITTED = 3

_ns_module._register_PrintBinding(PrintBinding)
_ns_module._register_PrintBordering(PrintBordering)
_ns_module._register_PrintCollation(PrintCollation)
_ns_module._register_PrintColorMode(PrintColorMode)
_ns_module._register_PrintDuplex(PrintDuplex)
_ns_module._register_PrintHolePunch(PrintHolePunch)
_ns_module._register_PrintMediaSize(PrintMediaSize)
_ns_module._register_PrintMediaType(PrintMediaType)
_ns_module._register_PrintOrientation(PrintOrientation)
_ns_module._register_PrintQuality(PrintQuality)
_ns_module._register_PrintStaple(PrintStaple)
_ns_module._register_PrintTaskCompletion(PrintTaskCompletion)

PrintPageDescription = _ns_module.PrintPageDescription
PrintManager = _ns_module.PrintManager
PrintPageInfo = _ns_module.PrintPageInfo
PrintPageRange = _ns_module.PrintPageRange
PrintPageRangeOptions = _ns_module.PrintPageRangeOptions
PrintTask = _ns_module.PrintTask
PrintTaskCompletedEventArgs = _ns_module.PrintTaskCompletedEventArgs
PrintTaskOptions = _ns_module.PrintTaskOptions
PrintTaskProgressingEventArgs = _ns_module.PrintTaskProgressingEventArgs
PrintTaskRequest = _ns_module.PrintTaskRequest
PrintTaskRequestedDeferral = _ns_module.PrintTaskRequestedDeferral
PrintTaskRequestedEventArgs = _ns_module.PrintTaskRequestedEventArgs
PrintTaskSourceRequestedArgs = _ns_module.PrintTaskSourceRequestedArgs
PrintTaskSourceRequestedDeferral = _ns_module.PrintTaskSourceRequestedDeferral
StandardPrintTaskOptions = _ns_module.StandardPrintTaskOptions
IPrintDocumentSource = _ns_module.IPrintDocumentSource
IPrintTaskOptionsCore = _ns_module.IPrintTaskOptionsCore
IPrintTaskOptionsCoreProperties = _ns_module.IPrintTaskOptionsCoreProperties
IPrintTaskOptionsCoreUIConfiguration = _ns_module.IPrintTaskOptionsCoreUIConfiguration



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

Self = typing.TypeVar('Self')

class BackPressedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BackPressedEventArgs: ...

class CameraEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraEventArgs: ...

class HardwareButtons(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HardwareButtons: ...
    @staticmethod
    def add_back_pressed(handler: winsdk.windows.foundation.EventHandler[BackPressedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_back_pressed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_camera_half_pressed(handler: winsdk.windows.foundation.EventHandler[CameraEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_camera_half_pressed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_camera_pressed(handler: winsdk.windows.foundation.EventHandler[CameraEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_camera_pressed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_camera_released(handler: winsdk.windows.foundation.EventHandler[CameraEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_camera_released(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class Print3DWorkflowDetail(enum.IntEnum):
    UNKNOWN = 0
    MODEL_EXCEEDS_PRINT_BED = 1
    UPLOAD_FAILED = 2
    INVALID_MATERIAL_SELECTION = 3
    INVALID_MODEL = 4
    MODEL_NOT_MANIFOLD = 5
    INVALID_PRINT_TICKET = 6

class Print3DWorkflowStatus(enum.IntEnum):
    ABANDONED = 0
    CANCELED = 1
    FAILED = 2
    SLICING = 3
    SUBMITTED = 4

Self = typing.TypeVar('Self')

class Print3DWorkflow(winsdk.system.Object):
    is_print_ready: winsdk.system.Boolean
    device_i_d: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Print3DWorkflow: ...
    def get_print_model_package(self) -> typing.Optional[winsdk.system.Object]: ...
    def add_print_requested(self, event_handler: winsdk.windows.foundation.TypedEventHandler[Print3DWorkflow, Print3DWorkflowPrintRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_print_requested(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_printer_changed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[Print3DWorkflow, Print3DWorkflowPrinterChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_printer_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class Print3DWorkflowPrintRequestedEventArgs(winsdk.system.Object):
    status: Print3DWorkflowStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Print3DWorkflowPrintRequestedEventArgs: ...
    def set_extended_status(self, value: Print3DWorkflowDetail) -> None: ...
    def set_source(self, source: typing.Optional[winsdk.system.Object]) -> None: ...
    def set_source_changed(self, value: winsdk.system.Boolean) -> None: ...

class Print3DWorkflowPrinterChangedEventArgs(winsdk.system.Object):
    new_device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Print3DWorkflowPrinterChangedEventArgs: ...

class PrintExtensionContext(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintExtensionContext: ...
    @staticmethod
    def from_device_id(device_id: str) -> typing.Optional[winsdk.system.Object]: ...

class PrintNotificationEventDetails(winsdk.system.Object):
    event_data: str
    printer_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintNotificationEventDetails: ...

class PrintTaskConfiguration(winsdk.system.Object):
    printer_extension_context: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfiguration: ...
    def add_save_requested(self, event_handler: winsdk.windows.foundation.TypedEventHandler[PrintTaskConfiguration, PrintTaskConfigurationSaveRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_save_requested(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PrintTaskConfigurationSaveRequest(winsdk.system.Object):
    deadline: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfigurationSaveRequest: ...
    def cancel(self) -> None: ...
    def get_deferral(self) -> typing.Optional[PrintTaskConfigurationSaveRequestedDeferral]: ...
    def save(self, printer_extension_context: typing.Optional[winsdk.system.Object]) -> None: ...

class PrintTaskConfigurationSaveRequestedDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfigurationSaveRequestedDeferral: ...
    def complete(self) -> None: ...

class PrintTaskConfigurationSaveRequestedEventArgs(winsdk.system.Object):
    request: typing.Optional[PrintTaskConfigurationSaveRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintTaskConfigurationSaveRequestedEventArgs: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Store")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class FulfillmentResult(enum.IntEnum):
    SUCCEEDED = 0
    NOTHING_TO_FULFILL = 1
    PURCHASE_PENDING = 2
    PURCHASE_REVERTED = 3
    SERVER_ERROR = 4

class ProductPurchaseStatus(enum.IntEnum):
    SUCCEEDED = 0
    ALREADY_PURCHASED = 1
    NOT_FULFILLED = 2
    NOT_PURCHASED = 3

class ProductType(enum.IntEnum):
    UNKNOWN = 0
    DURABLE = 1
    CONSUMABLE = 2

_ns_module._register_FulfillmentResult(FulfillmentResult)
_ns_module._register_ProductPurchaseStatus(ProductPurchaseStatus)
_ns_module._register_ProductType(ProductType)

CurrentApp = _ns_module.CurrentApp
CurrentAppSimulator = _ns_module.CurrentAppSimulator
LicenseInformation = _ns_module.LicenseInformation
ListingInformation = _ns_module.ListingInformation
ProductLicense = _ns_module.ProductLicense
ProductListing = _ns_module.ProductListing
ProductPurchaseDisplayProperties = _ns_module.ProductPurchaseDisplayProperties
PurchaseResults = _ns_module.PurchaseResults
UnfulfilledConsumable = _ns_module.UnfulfilledConsumable



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class PowerSavingMode(enum.IntEnum):
    OFF = 0
    ON = 1

Self = typing.TypeVar('Self')

class PowerManager(winsdk.system.Object):
    power_saving_mode: typing.ClassVar[PowerSavingMode]
    power_saving_mode_enabled: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PowerManager: ...
    @staticmethod
    def add_power_saving_mode_changed(change_handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_power_saving_mode_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class CellularClass(enum.IntEnum):
    NONE = 0
    GSM = 1
    CDMA = 2

class SmsBroadcastType(enum.IntEnum):
    OTHER = 0
    CMAS_PRESIDENTIAL = 1
    CMAS_EXTREME = 2
    CMAS_SEVERE = 3
    CMAS_AMBER = 4
    CMAS_TEST = 5
    E_U_ALERT1 = 6
    E_U_ALERT2 = 7
    E_U_ALERT3 = 8
    E_U_ALERT_AMBER = 9
    E_U_ALERT_INFO = 10
    ETWS_EARTHQUAKE = 11
    ETWS_TSUNAMI = 12
    ETWS_TSUNAMI_AND_EARTHQUAKE = 13
    LAT_ALERT_LOCAL = 14

class SmsDataFormat(enum.IntEnum):
    UNKNOWN = 0
    CDMA_SUBMIT = 1
    GSM_SUBMIT = 2
    CDMA_DELIVER = 3
    GSM_DELIVER = 4

class SmsDeviceStatus(enum.IntEnum):
    OFF = 0
    READY = 1
    SIM_NOT_INSERTED = 2
    BAD_SIM = 3
    DEVICE_FAILURE = 4
    SUBSCRIPTION_NOT_ACTIVATED = 5
    DEVICE_LOCKED = 6
    DEVICE_BLOCKED = 7

class SmsEncoding(enum.IntEnum):
    UNKNOWN = 0
    OPTIMAL = 1
    SEVEN_BIT_ASCII = 2
    UNICODE = 3
    GSM_SEVEN_BIT = 4
    EIGHT_BIT = 5
    LATIN = 6
    KOREAN = 7
    I_A5 = 8
    SHIFT_JIS = 9
    LATIN_HEBREW = 10

class SmsFilterActionType(enum.IntEnum):
    ACCEPT_IMMEDIATELY = 0
    DROP = 1
    PEEK = 2
    ACCEPT = 3

class SmsGeographicalScope(enum.IntEnum):
    NONE = 0
    CELL_WITH_IMMEDIATE_DISPLAY = 1
    LOCATION_AREA = 2
    PLMN = 3
    CELL = 4

class SmsMessageClass(enum.IntEnum):
    NONE = 0
    CLASS0 = 1
    CLASS1 = 2
    CLASS2 = 3
    CLASS3 = 4

class SmsMessageFilter(enum.IntEnum):
    ALL = 0
    UNREAD = 1
    READ = 2
    SENT = 3
    DRAFT = 4

class SmsMessageType(enum.IntEnum):
    BINARY = 0
    TEXT = 1
    WAP = 2
    APP = 3
    BROADCAST = 4
    VOICEMAIL = 5
    STATUS = 6

class SmsModemErrorCode(enum.IntEnum):
    OTHER = 0
    MESSAGING_NETWORK_ERROR = 1
    SMS_OPERATION_NOT_SUPPORTED_BY_DEVICE = 2
    SMS_SERVICE_NOT_SUPPORTED_BY_NETWORK = 3
    DEVICE_FAILURE = 4
    MESSAGE_NOT_ENCODED_PROPERLY = 5
    MESSAGE_TOO_LARGE = 6
    DEVICE_NOT_READY = 7
    NETWORK_NOT_READY = 8
    INVALID_SMSC_ADDRESS = 9
    NETWORK_FAILURE = 10
    FIXED_DIALING_NUMBER_RESTRICTED = 11

Self = typing.TypeVar('Self')

class SmsEncodedLength:
    segment_count: winsdk.system.UInt32
    character_count_last_segment: winsdk.system.UInt32
    characters_per_segment: winsdk.system.UInt32
    byte_count_last_segment: winsdk.system.UInt32
    bytes_per_segment: winsdk.system.UInt32
    def __new__(cls: typing.Type[SmsEncodedLength], segment_count: winsdk.system.UInt32, character_count_last_segment: winsdk.system.UInt32, characters_per_segment: winsdk.system.UInt32, byte_count_last_segment: winsdk.system.UInt32, bytes_per_segment: winsdk.system.UInt32) -> SmsEncodedLength: ...

class DeleteSmsMessageOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncActionCompletedHandler]
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeleteSmsMessageOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...

class DeleteSmsMessagesOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncActionCompletedHandler]
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DeleteSmsMessagesOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...

class GetSmsDeviceOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncOperationCompletedHandler[SmsDevice]]
    def __await__(self) -> typing.Generator[typing.Any, None, typing.Optional[SmsDevice]]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GetSmsDeviceOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[SmsDevice]: ...

class GetSmsMessageOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncOperationCompletedHandler[ISmsMessage]]
    def __await__(self) -> typing.Generator[typing.Any, None, typing.Optional[ISmsMessage]]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GetSmsMessageOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[ISmsMessage]: ...

class GetSmsMessagesOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    progress: typing.Optional[winsdk.windows.foundation.AsyncOperationProgressHandler[winsdk.windows.foundation.collections.IVectorView[ISmsMessage], winsdk.system.Int32]]
    completed: typing.Optional[winsdk.windows.foundation.AsyncOperationWithProgressCompletedHandler[winsdk.windows.foundation.collections.IVectorView[ISmsMessage], winsdk.system.Int32]]
    def __await__(self) -> typing.Generator[typing.Any, None, typing.Optional[winsdk.windows.foundation.collections.IVectorView[ISmsMessage]]]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GetSmsMessagesOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[ISmsMessage]]: ...

class SendSmsMessageOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncActionCompletedHandler]
    def __await__(self) -> typing.Generator[typing.Any, None, None]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SendSmsMessageOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> None: ...

class SmsAppMessage(winsdk.system.Object):
    protocol_id: winsdk.system.Int32
    port_number: winsdk.system.Int32
    is_delivery_notification_enabled: winsdk.system.Boolean
    retry_attempt_count: winsdk.system.Int32
    encoding: SmsEncoding
    body: str
    callback_number: str
    binary_body: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    to: str
    teleservice_id: winsdk.system.Int32
    from_: str
    timestamp: datetime.datetime
    cellular_class: CellularClass
    device_id: str
    message_class: SmsMessageClass
    message_type: SmsMessageType
    sim_icc_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsAppMessage: ...
    def __new__(cls: typing.Type[SmsAppMessage]) -> SmsAppMessage:...

class SmsBinaryMessage(winsdk.system.Object):
    format: SmsDataFormat
    id: winsdk.system.UInt32
    message_class: SmsMessageClass
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsBinaryMessage: ...
    def __new__(cls: typing.Type[SmsBinaryMessage]) -> SmsBinaryMessage:...
    def get_data(self) -> winsdk.system.UInt8: ...
    def set_data(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class SmsBroadcastMessage(winsdk.system.Object):
    body: str
    broadcast_type: SmsBroadcastType
    channel: winsdk.system.Int32
    geographical_scope: SmsGeographicalScope
    is_emergency_alert: winsdk.system.Boolean
    is_user_popup_requested: winsdk.system.Boolean
    message_code: winsdk.system.Int32
    timestamp: datetime.datetime
    to: str
    update_number: winsdk.system.Int32
    cellular_class: CellularClass
    device_id: str
    message_class: SmsMessageClass
    message_type: SmsMessageType
    sim_icc_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsBroadcastMessage: ...

class SmsDevice(winsdk.system.Object):
    account_phone_number: str
    cellular_class: CellularClass
    device_status: SmsDeviceStatus
    message_store: typing.Optional[SmsDeviceMessageStore]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsDevice: ...
    def calculate_length(self, message: typing.Optional[SmsTextMessage]) -> SmsEncodedLength: ...
    @staticmethod
    def from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[SmsDevice]: ...
    @staticmethod
    def from_network_account_id_async(network_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[SmsDevice]: ...
    @staticmethod
    def get_default_async() -> winsdk.windows.foundation.IAsyncOperation[SmsDevice]: ...
    @staticmethod
    def get_device_selector() -> str: ...
    def send_message_async(self, message: typing.Optional[ISmsMessage]) -> SendSmsMessageOperation: ...
    def add_sms_device_status_changed(self, event_handler: typing.Optional[SmsDeviceStatusChangedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sms_device_status_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_sms_message_received(self, event_handler: typing.Optional[SmsMessageReceivedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sms_message_received(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SmsDevice2(winsdk.system.Object):
    smsc_address: str
    account_phone_number: str
    cellular_class: CellularClass
    device_id: str
    device_status: SmsDeviceStatus
    parent_device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsDevice2: ...
    def calculate_length(self, message: typing.Optional[ISmsMessageBase]) -> SmsEncodedLength: ...
    @staticmethod
    def from_id(device_id: str) -> typing.Optional[SmsDevice2]: ...
    @staticmethod
    def from_parent_id(parent_device_id: str) -> typing.Optional[SmsDevice2]: ...
    @staticmethod
    def get_default() -> typing.Optional[SmsDevice2]: ...
    @staticmethod
    def get_device_selector() -> str: ...
    def send_message_and_get_result_async(self, message: typing.Optional[ISmsMessageBase]) -> winsdk.windows.foundation.IAsyncOperation[SmsSendMessageResult]: ...
    def add_device_status_changed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[SmsDevice2, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_device_status_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SmsDeviceMessageStore(winsdk.system.Object):
    max_messages: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsDeviceMessageStore: ...
    def delete_message_async(self, message_id: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete_messages_async(self, message_filter: SmsMessageFilter) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_message_async(self, message_id: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[ISmsMessage]: ...
    def get_messages_async(self, message_filter: SmsMessageFilter) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.foundation.collections.IVectorView[ISmsMessage], winsdk.system.Int32]: ...

class SmsFilterRule(winsdk.system.Object):
    cellular_class: CellularClass
    broadcast_channels: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Int32]]
    broadcast_types: typing.Optional[winsdk.windows.foundation.collections.IVector[SmsBroadcastType]]
    device_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    imsi_prefixes: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    message_type: SmsMessageType
    port_numbers: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Int32]]
    protocol_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Int32]]
    sender_numbers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    teleservice_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Int32]]
    text_message_prefixes: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    wap_application_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    wap_content_types: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsFilterRule: ...
    def __new__(cls: typing.Type[SmsFilterRule], message_type: SmsMessageType) -> SmsFilterRule:...

class SmsFilterRules(winsdk.system.Object):
    action_type: SmsFilterActionType
    rules: typing.Optional[winsdk.windows.foundation.collections.IVector[SmsFilterRule]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsFilterRules: ...
    def __new__(cls: typing.Type[SmsFilterRules], action_type: SmsFilterActionType) -> SmsFilterRules:...

class SmsMessageReceivedEventArgs(winsdk.system.Object):
    binary_message: typing.Optional[SmsBinaryMessage]
    text_message: typing.Optional[SmsTextMessage]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsMessageReceivedEventArgs: ...

class SmsMessageReceivedTriggerDetails(winsdk.system.Object):
    app_message: typing.Optional[SmsAppMessage]
    broadcast_message: typing.Optional[SmsBroadcastMessage]
    message_type: SmsMessageType
    status_message: typing.Optional[SmsStatusMessage]
    text_message: typing.Optional[SmsTextMessage2]
    voicemail_message: typing.Optional[SmsVoicemailMessage]
    wap_message: typing.Optional[SmsWapMessage]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsMessageReceivedTriggerDetails: ...
    def accept(self) -> None: ...
    def drop(self) -> None: ...

class SmsMessageRegistration(winsdk.system.Object):
    id: str
    all_registrations: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[SmsMessageRegistration]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsMessageRegistration: ...
    @staticmethod
    def register(id: str, filter_rules: typing.Optional[SmsFilterRules]) -> typing.Optional[SmsMessageRegistration]: ...
    def unregister(self) -> None: ...
    def add_message_received(self, event_handler: winsdk.windows.foundation.TypedEventHandler[SmsMessageRegistration, SmsMessageReceivedTriggerDetails]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_message_received(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SmsReceivedEventDetails(winsdk.system.Object):
    device_id: str
    message_index: winsdk.system.UInt32
    binary_message: typing.Optional[SmsBinaryMessage]
    message_class: SmsMessageClass
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsReceivedEventDetails: ...

class SmsSendMessageResult(winsdk.system.Object):
    cellular_class: CellularClass
    is_error_transient: winsdk.system.Boolean
    is_successful: winsdk.system.Boolean
    message_reference_numbers: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.system.Int32]]
    modem_error_code: SmsModemErrorCode
    network_cause_code: winsdk.system.Int32
    transport_failure_cause: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsSendMessageResult: ...

class SmsStatusMessage(winsdk.system.Object):
    cellular_class: CellularClass
    device_id: str
    message_class: SmsMessageClass
    message_type: SmsMessageType
    sim_icc_id: str
    status: winsdk.system.Int32
    body: str
    discharge_time: datetime.datetime
    from_: str
    message_reference_number: winsdk.system.Int32
    service_center_timestamp: datetime.datetime
    to: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsStatusMessage: ...

class SmsTextMessage(winsdk.system.Object):
    id: winsdk.system.UInt32
    message_class: SmsMessageClass
    to: str
    from_: str
    encoding: SmsEncoding
    body: str
    part_count: winsdk.system.UInt32
    part_number: winsdk.system.UInt32
    part_reference_id: winsdk.system.UInt32
    timestamp: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsTextMessage: ...
    def __new__(cls: typing.Type[SmsTextMessage]) -> SmsTextMessage:...
    @staticmethod
    def from_binary_data(format: SmsDataFormat, value: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[SmsTextMessage]: ...
    @staticmethod
    def from_binary_message(binary_message: typing.Optional[SmsBinaryMessage]) -> typing.Optional[SmsTextMessage]: ...
    def to_binary_messages(self, format: SmsDataFormat) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[ISmsBinaryMessage]]: ...

class SmsTextMessage2(winsdk.system.Object):
    message_type: SmsMessageType
    device_id: str
    cellular_class: CellularClass
    message_class: SmsMessageClass
    sim_icc_id: str
    retry_attempt_count: winsdk.system.Int32
    to: str
    is_delivery_notification_enabled: winsdk.system.Boolean
    encoding: SmsEncoding
    callback_number: str
    body: str
    protocol_id: winsdk.system.Int32
    from_: str
    timestamp: datetime.datetime
    teleservice_id: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsTextMessage2: ...
    def __new__(cls: typing.Type[SmsTextMessage2]) -> SmsTextMessage2:...

class SmsVoicemailMessage(winsdk.system.Object):
    cellular_class: CellularClass
    device_id: str
    message_class: SmsMessageClass
    message_type: SmsMessageType
    sim_icc_id: str
    body: str
    message_count: typing.Optional[typing.Optional[winsdk.system.Int32]]
    timestamp: datetime.datetime
    to: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsVoicemailMessage: ...

class SmsWapMessage(winsdk.system.Object):
    cellular_class: CellularClass
    device_id: str
    message_class: SmsMessageClass
    message_type: SmsMessageType
    sim_icc_id: str
    timestamp: datetime.datetime
    application_id: str
    binary_body: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    content_type: str
    from_: str
    headers: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    to: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SmsWapMessage: ...

class ISmsBinaryMessage(winsdk.system.Object):
    format: SmsDataFormat
    id: winsdk.system.UInt32
    message_class: SmsMessageClass
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISmsBinaryMessage: ...
    def get_data(self) -> winsdk.system.UInt8: ...
    def set_data(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class ISmsDevice(winsdk.system.Object):
    account_phone_number: str
    cellular_class: CellularClass
    device_status: SmsDeviceStatus
    message_store: typing.Optional[SmsDeviceMessageStore]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISmsDevice: ...
    def calculate_length(self, message: typing.Optional[SmsTextMessage]) -> SmsEncodedLength: ...
    def send_message_async(self, message: typing.Optional[ISmsMessage]) -> SendSmsMessageOperation: ...
    def add_sms_device_status_changed(self, event_handler: typing.Optional[SmsDeviceStatusChangedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sms_device_status_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_sms_message_received(self, event_handler: typing.Optional[SmsMessageReceivedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sms_message_received(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ISmsMessage(winsdk.system.Object):
    id: winsdk.system.UInt32
    message_class: SmsMessageClass
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISmsMessage: ...

class ISmsMessageBase(winsdk.system.Object):
    cellular_class: CellularClass
    device_id: str
    message_class: SmsMessageClass
    message_type: SmsMessageType
    sim_icc_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISmsMessageBase: ...

class ISmsTextMessage(winsdk.system.Object):
    body: str
    encoding: SmsEncoding
    from_: str
    part_count: winsdk.system.UInt32
    part_number: winsdk.system.UInt32
    part_reference_id: winsdk.system.UInt32
    timestamp: datetime.datetime
    to: str
    id: winsdk.system.UInt32
    message_class: SmsMessageClass
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ISmsTextMessage: ...
    def to_binary_messages(self, format: SmsDataFormat) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[ISmsBinaryMessage]]: ...

SmsDeviceStatusChangedEventHandler = typing.Callable[[typing.Optional[SmsDevice]], None]

SmsMessageReceivedEventHandler = typing.Callable[[typing.Optional[SmsDevice], typing.Optional[SmsMessageReceivedEventArgs]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class SystemProtection(winsdk.system.Object):
    screen_locked: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemProtection: ...
    @staticmethod
    def request_screen_unlock() -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.PersonalInformation.Provisioning")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.phone.personalinformation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


ContactPartnerProvisioningManager = _ns_module.ContactPartnerProvisioningManager
MessagePartnerProvisioningManager = _ns_module.MessagePartnerProvisioningManager



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Perception.Automation.Core")

try:
    import winsdk.windows.foundation
except ImportError:
    pass


CorePerceptionAutomation = _ns_module.CorePerceptionAutomation



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage

class AppRecordingSaveScreenshotOption(enum.IntEnum):
    NONE = 0
    HDR_CONTENT_VISIBLE = 1

Self = typing.TypeVar('Self')

class AppRecordingManager(winsdk.system.Object):
    supported_screenshot_media_encoding_subtypes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppRecordingManager: ...
    @staticmethod
    def get_default() -> typing.Optional[AppRecordingManager]: ...
    def get_status(self) -> typing.Optional[AppRecordingStatus]: ...
    def record_time_span_to_file_async(self, start_time: datetime.datetime, duration: datetime.timedelta, file: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncOperation[AppRecordingResult]: ...
    def save_screenshot_to_files_async(self, folder: typing.Optional[winsdk.windows.storage.StorageFolder], filename_prefix: str, option: AppRecordingSaveScreenshotOption, requested_formats: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[AppRecordingSaveScreenshotResult]: ...
    def start_recording_to_file_async(self, file: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncOperation[AppRecordingResult]: ...

class AppRecordingResult(winsdk.system.Object):
    duration: datetime.timedelta
    extended_error: winsdk.windows.foundation.HResult
    is_file_truncated: winsdk.system.Boolean
    succeeded: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppRecordingResult: ...

class AppRecordingSaveScreenshotResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    saved_screenshot_infos: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AppRecordingSavedScreenshotInfo]]
    succeeded: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppRecordingSaveScreenshotResult: ...

class AppRecordingSavedScreenshotInfo(winsdk.system.Object):
    file: typing.Optional[winsdk.windows.storage.StorageFile]
    media_encoding_subtype: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppRecordingSavedScreenshotInfo: ...

class AppRecordingStatus(winsdk.system.Object):
    can_record: winsdk.system.Boolean
    can_record_time_span: winsdk.system.Boolean
    details: typing.Optional[AppRecordingStatusDetails]
    historical_buffer_duration: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppRecordingStatus: ...

class AppRecordingStatusDetails(winsdk.system.Object):
    is_any_app_broadcasting: winsdk.system.Boolean
    is_app_inactive: winsdk.system.Boolean
    is_blocked_for_app: winsdk.system.Boolean
    is_capture_resource_unavailable: winsdk.system.Boolean
    is_disabled_by_system: winsdk.system.Boolean
    is_disabled_by_user: winsdk.system.Boolean
    is_game_stream_in_progress: winsdk.system.Boolean
    is_gpu_constrained: winsdk.system.Boolean
    is_time_span_recording_disabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppRecordingStatusDetails: ...

